####################
Line Measurer (LiMe)
####################

This library provides a set of tools to fit lines in astronomical spectra. Its design aims for a user-friendly workflow
for both single lines and large data sets. The library provides tools for masking, detecting, profile fitting
and storing the results. The output measurements support both the posterior analysis of the object's chemical composition
and plasma kinematics.

Please check the `online documentation <https://lime-stable.readthedocs.io/>`_.

Installation
============

The library can be installed directly from its pip_ project page running the command:

``pip install lime-stable``

Development
===========

LiMe is currently in a beta release. Please check its github_ for the latest version news and tutorials.
Any comment/issue/request can be added as an issue on the github_ page.

.. _pip: https://pypi.org/project/lime-stable/
.. _github: https://github.com/Vital-Fernandez/lime

